<?php
/** 
 * Plugin Name: Drug Search
 * Plugin URI: https://emdplugins.com
 * Description: Allows to search drugs using a search form
 * Version: 1.0.0
 * Author: eMarket Design
 * Author URI: https://emdplugins.com
 * Text Domain: drug-search
 * Domain Path: /lang
 * @package DRUG_SEARCH
 * @since WPAS 4.0
 */
/*
 * LICENSE:
 * Drug Search is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *
 * Drug Search is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * Please see <http://www.gnu.org/licenses/> for details.
*/
if (!defined('ABSPATH')) exit;
if (!class_exists('Drug_Search')):
	/**
	 * Main class for Drug Search
	 *
	 * @class Drug_Search
	 */
	final class Drug_Search {
		/**
		 * @var Drug_Search single instance of the class
		 */
		private static $_instance;
		public $textdomain = 'drug-search';
		public $app_name = 'drug_search';
		public $session;
		/**
		 * Main Drug_Search Instance
		 *
		 * Ensures only one instance of Drug_Search is loaded or can be loaded.
		 *
		 * @static
		 * @see DRUG_SEARCH()
		 * @return Drug_Search - Main instance
		 */
		public static function instance() {
			if (!isset(self::$_instance)) {
				self::$_instance = new self();
				self::$_instance->define_constants();
				self::$_instance->includes();
				self::$_instance->load_plugin_textdomain();
				self::$_instance->session = new Emd_Session('drug_search');
				add_filter('the_content', array(
					self::$_instance,
					'change_content'
				));
				add_action('admin_menu', array(
					self::$_instance,
					'display_settings'
				));
				add_filter('template_include', array(
					self::$_instance,
					'show_template'
				));
			}
			return self::$_instance;
		}
		/**
		 * Cloning is forbidden.
		 */
		public function __clone() {
			_doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?', $this->textdomain) , '1.0');
		}
		/**
		 * Define Drug_Search Constants
		 *
		 * @access private
		 * @return void
		 */
		private function define_constants() {
			define('DRUG_SEARCH_VERSION', '1.0.0');
			define('DRUG_SEARCH_AUTHOR', 'eMarket Design');
			define('DRUG_SEARCH_NAME', 'Drug Search');
			define('DRUG_SEARCH_PLUGIN_FILE', __FILE__);
			define('DRUG_SEARCH_PLUGIN_DIR', plugin_dir_path(__FILE__));
			define('DRUG_SEARCH_PLUGIN_URL', plugin_dir_url(__FILE__));
		}
		/**
		 * Include required files
		 *
		 * @access private
		 * @return void
		 */
		private function includes() {
			//these files are in all apps
			if (!function_exists('emd_mb_meta')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'assets/ext/emd-meta-box/emd-meta-box.php';
			}
			if (!function_exists('emd_translate_date_format')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/date-functions.php';
			}
			if (!function_exists('emd_get_hidden_func')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/common-functions.php';
			}
			if (!class_exists('Emd_Entity')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/entities/class-emd-entity.php';
			}
			if (!function_exists('emd_get_template_part')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/layout-functions.php';
			}
			if (!class_exists('EDD_SL_Plugin_Updater')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'assets/ext/edd/EDD_SL_Plugin_Updater.php';
			}
			if (!class_exists('Emd_License')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/admin/class-emd-license.php';
			}
			if (!function_exists('emd_show_license_page')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/admin/license-functions.php';
			}
			//the rest
			if (!class_exists('Emd_Query')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/class-emd-query.php';
			}
			if (!class_exists('Zebra_Form')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . '/assets/ext/zebraform/Zebra_Form.php';
			}
			if (!function_exists('emd_submit_form')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/form-functions.php';
			}
			if (!function_exists('emd_shc_get_layout_list')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/shortcode-functions.php';
			}
			if (!class_exists('Emd_Session')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/class-emd-session.php';
			}
			if (!function_exists('emd_show_login_register_forms')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/login-register-functions.php';
			}
			do_action('emd_ext_include_files');
			//app specific files
			if (!function_exists('emd_show_settings_page')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/admin/settings-functions.php';
			}
			if (!function_exists('emd_form_register_settings')) {
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/admin/settings-functions-forms.php';
			}
			if (is_admin()) {
				//these files are in all apps
				if (!function_exists('emd_display_store')) {
					require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/admin/store-functions.php';
				}
				//the rest
				if (!function_exists('emd_shc_button')) {
					require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/admin/wpas-btn-functions.php';
				}
				require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/admin/glossary.php';
			}
			require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/class-install-deactivate.php';
			require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/entities/class-emd-drug.php';
			require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/entities/emd-drug-shortcodes.php';
			require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/forms.php';
			require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/scripts.php';
			require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/plugin-feedback-functions.php';
			require_once DRUG_SEARCH_PLUGIN_DIR . 'includes/content-functions.php';
		}
		/**
		 * Loads plugin language files
		 *
		 * @access public
		 * @return void
		 */
		public function load_plugin_textdomain() {
			$locale = apply_filters('plugin_locale', get_locale() , 'drug-search');
			$mofile = sprintf('%1$s-%2$s.mo', 'drug-search', $locale);
			$mofile_shared = sprintf('%1$s-emd-plugins-%2$s.mo', 'drug-search', $locale);
			$lang_file_list = Array(
				'emd-plugins' => $mofile_shared,
				'drug-search' => $mofile
			);
			foreach ($lang_file_list as $lang_key => $lang_file) {
				$localmo = DRUG_SEARCH_PLUGIN_DIR . '/lang/' . $lang_file;
				$globalmo = WP_LANG_DIR . '/drug-search/' . $lang_file;
				if (file_exists($globalmo)) {
					load_textdomain($lang_key, $globalmo);
				} elseif (file_exists($localmo)) {
					load_textdomain($lang_key, $localmo);
				} else {
					load_plugin_textdomain($lang_key, false, DRUG_SEARCH_PLUGIN_DIR . '/lang/');
				}
			}
		}
		/**
		 * Changes content on frontend views
		 *
		 * @access public
		 * @param string $content
		 *
		 * @return string $content
		 */
		public function change_content($content) {
			if (!is_admin()) {
				if (post_password_required()) {
					$content = get_the_password_form();
				} else {
					$mypost_type = get_post_type();
					if ($mypost_type == 'post' || $mypost_type == 'page') {
						$mypost_type = "emd_" . $mypost_type;
					}
					$ent_list = get_option($this->app_name . '_ent_list');
					if (in_array($mypost_type, array_keys($ent_list)) && class_exists($mypost_type)) {
						$func = "change_content";
						$obj = new $mypost_type;
						$content = $obj->$func($content);
					}
				}
			}
			return $content;
		}
		/**
		 * Creates plugin page in menu with submenus
		 *
		 * @access public
		 * @return void
		 */
		public function display_settings() {
			add_menu_page(__('Drug Search', $this->textdomain) , __('Drug Search', $this->textdomain) , 'manage_options', $this->app_name, array(
				$this,
				'display_glossary_page'
			));
			add_submenu_page($this->app_name, __('Glossary', $this->textdomain) , __('Glossary', $this->textdomain) , 'manage_options', $this->app_name, array(
				$this,
				'display_glossary_page'
			));
			add_submenu_page($this->app_name, __('Settings', $this->textdomain) , __('Settings', $this->textdomain) , 'manage_options', $this->app_name . '_settings', array(
				$this,
				'display_settings_page'
			));
			add_submenu_page($this->app_name, __('Plugins', $this->textdomain) , __('Plugins', $this->textdomain) , 'manage_options', $this->app_name . '_store', array(
				$this,
				'display_store_page'
			));
			add_submenu_page($this->app_name, __('Support', $this->textdomain) , __('Support', $this->textdomain) , 'manage_options', $this->app_name . '_support', array(
				$this,
				'display_support_page'
			));
			//add submenu page under app settings page
			do_action('emd_ext_add_menu_pages', $this->app_name);
			$emd_lic_settings = get_option('emd_license_settings', Array());
			$show_lic_page = 0;
			if (!empty($emd_lic_settings)) {
				foreach ($emd_lic_settings as $key => $val) {
					if ($key == $this->app_name) {
						$show_lic_page = 1;
						break;
					} else if ($val['type'] == 'ext') {
						$show_lic_page = 1;
						break;
					}
				}
				if ($show_lic_page == 1) {
					add_submenu_page($this->app_name, __('Licenses', $this->textdomain) , __('Licenses', $this->textdomain) , 'manage_options', $this->app_name . '_licenses', array(
						$this,
						'display_licenses_page'
					));
				}
			}
		}
		/**
		 * Calls settings function to display glossary page
		 *
		 * @access public
		 * @return void
		 */
		public function display_glossary_page() {
			do_action($this->app_name . '_settings_glossary');
		}
		public function display_store_page() {
			emd_display_store($this->textdomain);
		}
		public function display_support_page() {
			emd_display_support($this->textdomain, 2, 'drug-search');
		}
		public function display_licenses_page() {
			do_action('emd_show_license_page', $this->app_name);
		}
		public function display_settings_page() {
			do_action('emd_show_settings_page', $this->app_name);
		}
		/**
		 * Displays single, archive, tax and no-access frontend views
		 *
		 * @access public
		 * @return string, $template:emd template or template
		 */
		public function show_template($template) {
			return emd_show_template($this->app_name, DRUG_SEARCH_PLUGIN_DIR, $template);
		}
	}
endif;
/**
 * Returns the main instance of Drug_Search
 *
 * @return Drug_Search
 */
function DRUG_SEARCH() {
	return Drug_Search::instance();
}
// Get the Drug_Search instance
DRUG_SEARCH();
