<?php
/**
 * Install and Deactivate Plugin Functions
 * @package DRUG_SEARCH
 * @since WPAS 4.0
 */
if (!defined('ABSPATH')) exit;
if (!class_exists('Drug_Search_Install_Deactivate')):
	/**
	 * Drug_Search_Install_Deactivate Class
	 * @since WPAS 4.0
	 */
	class Drug_Search_Install_Deactivate {
		private $option_name;
		/**
		 * Hooks for install and deactivation and create options
		 * @since WPAS 4.0
		 */
		public function __construct() {
			$this->option_name = 'drug_search';
			add_action('admin_init', array(
				$this,
				'check_update'
			));
			register_activation_hook(DRUG_SEARCH_PLUGIN_FILE, array(
				$this,
				'install'
			));
			register_deactivation_hook(DRUG_SEARCH_PLUGIN_FILE, array(
				$this,
				'deactivate'
			));
			add_action('wp_head', array(
				$this,
				'version_in_header'
			));
			add_action('admin_init', array(
				$this,
				'setup_pages'
			));
			add_action('admin_notices', array(
				$this,
				'install_notice'
			));
			add_action('admin_init', array(
				$this,
				'register_settings'
			) , 0);
			add_action('init', array(
				$this,
				'init_extensions'
			) , 99);
			do_action('emd_ext_actions', $this->option_name);
			add_filter('tiny_mce_before_init', array(
				$this,
				'tinymce_fix'
			));
		}
		public function check_update() {
			$curr_version = get_option($this->option_name . '_version', 1);
			$new_version = constant(strtoupper($this->option_name) . '_VERSION');
			if (version_compare($curr_version, $new_version, '<')) {
				$this->set_options();
				$this->set_roles_caps();
				if (!get_option($this->option_name . '_activation_date')) {
					$triggerdate = mktime(0, 0, 0, date('m') , date('d') + 7, date('Y'));
					add_option($this->option_name . '_activation_date', $triggerdate);
				}
				set_transient($this->option_name . '_activate_redirect', true, 30);
				do_action($this->option_name . '_upgrade', $new_version);
				update_option($this->option_name . '_version', $new_version);
			}
		}
		public function version_in_header() {
			$version = constant(strtoupper($this->option_name) . '_VERSION');
			$name = constant(strtoupper($this->option_name) . '_NAME');
			echo '<meta name="generator" content="' . $name . ' v' . $version . ' - https://emdplugins.com" />' . "\n";
		}
		public function init_extensions() {
			do_action('emd_ext_init', $this->option_name);
		}
		/**
		 * Runs on plugin install to setup custom post types and taxonomies
		 * flushing rewrite rules, populates settings and options
		 * creates roles and assign capabilities
		 * @since WPAS 4.0
		 *
		 */
		public function install() {
			$this->set_options();
			Emd_Drug::register();
			flush_rewrite_rules();
			$this->set_roles_caps();
			set_transient($this->option_name . '_activate_redirect', true, 30);
			do_action('emd_ext_install_hook', $this->option_name);
		}
		/**
		 * Runs on plugin deactivate to remove options, caps and roles
		 * flushing rewrite rules
		 * @since WPAS 4.0
		 *
		 */
		public function deactivate() {
			flush_rewrite_rules();
			$this->remove_caps_roles();
			$this->reset_options();
			do_action('emd_ext_deactivate', $this->option_name);
		}
		/**
		 * Register notification and/or license settings
		 * @since WPAS 4.0
		 *
		 */
		public function register_settings() {
			do_action('emd_ext_register', $this->option_name);
			if (!get_transient($this->option_name . '_activate_redirect')) {
				return;
			}
			// Delete the redirect transient.
			delete_transient($this->option_name . '_activate_redirect');
			$query_args = array(
				'page' => $this->option_name
			);
			wp_safe_redirect(add_query_arg($query_args, admin_url('admin.php')));
		}
		/**
		 * Sets caps and roles
		 *
		 * @since WPAS 4.0
		 *
		 */
		public function set_roles_caps() {
			global $wp_roles;
			$cust_roles = Array();
			update_option($this->option_name . '_cust_roles', $cust_roles);
			$add_caps = Array(
				'edit_manufacturer' => Array(
					'administrator'
				) ,
				'edit_drug_class' => Array(
					'administrator'
				) ,
				'assign_availability' => Array(
					'administrator'
				) ,
				'manage_availability' => Array(
					'administrator'
				) ,
				'view_drug_search_dashboard' => Array(
					'administrator'
				) ,
				'manage_operations_emd_drugs' => Array(
					'administrator'
				) ,
				'assign_pregnancy_category' => Array(
					'administrator'
				) ,
				'delete_availability' => Array(
					'administrator'
				) ,
				'edit_availability' => Array(
					'administrator'
				) ,
				'delete_manufacturer' => Array(
					'administrator'
				) ,
				'manage_drug_class' => Array(
					'administrator'
				) ,
				'assign_drug_class' => Array(
					'administrator'
				) ,
				'delete_pregnancy_category' => Array(
					'administrator'
				) ,
				'edit_pregnancy_category' => Array(
					'administrator'
				) ,
				'assign_manufacturer' => Array(
					'administrator'
				) ,
				'manage_manufacturer' => Array(
					'administrator'
				) ,
				'delete_drug_class' => Array(
					'administrator'
				) ,
				'manage_pregnancy_category' => Array(
					'administrator'
				) ,
				'edit_emd_drugs' => Array(
					'administrator'
				) ,
			);
			update_option($this->option_name . '_add_caps', $add_caps);
			if (class_exists('WP_Roles')) {
				if (!isset($wp_roles)) {
					$wp_roles = new WP_Roles();
				}
			}
			if (is_object($wp_roles)) {
				if (!empty($cust_roles)) {
					foreach ($cust_roles as $krole => $vrole) {
						$myrole = get_role($krole);
						if (empty($myrole)) {
							$myrole = add_role($krole, $vrole);
						}
					}
				}
				$this->set_reset_caps($wp_roles, 'add');
			}
		}
		/**
		 * Removes caps and roles
		 *
		 * @since WPAS 4.0
		 *
		 */
		public function remove_caps_roles() {
			global $wp_roles;
			if (class_exists('WP_Roles')) {
				if (!isset($wp_roles)) {
					$wp_roles = new WP_Roles();
				}
			}
			if (is_object($wp_roles)) {
				$this->set_reset_caps($wp_roles, 'remove');
			}
		}
		/**
		 * Set  capabilities
		 *
		 * @since WPAS 4.0
		 * @param object $wp_roles
		 * @param string $type
		 *
		 */
		public function set_reset_caps($wp_roles, $type) {
			$caps['enable'] = get_option($this->option_name . '_add_caps', Array());
			$caps['enable'] = apply_filters('emd_ext_get_caps', $caps['enable'], $this->option_name);
			foreach ($caps as $stat => $role_caps) {
				foreach ($role_caps as $mycap => $roles) {
					foreach ($roles as $myrole) {
						if (($type == 'add' && $stat == 'enable') || ($stat == 'disable' && $type == 'remove')) {
							$wp_roles->add_cap($myrole, $mycap);
						} else if (($type == 'remove' && $stat == 'enable') || ($type == 'add' && $stat == 'disable')) {
							$wp_roles->remove_cap($myrole, $mycap);
						}
					}
				}
			}
		}
		/**
		 * Set app specific options
		 *
		 * @since WPAS 4.0
		 *
		 */
		private function set_options() {
			$access_views = Array();
			if (get_option($this->option_name . '_setup_pages', 0) == 0) {
				update_option($this->option_name . '_setup_pages', 1);
			}
			$ent_list = Array(
				'emd_drug' => Array(
					'label' => __('Drugs', 'drug-search') ,
					'rewrite' => 'emd_drug',
					'archive_view' => 0,
					'featured_img' => 1,
					'rest_api' => 0,
					'sortable' => 0,
					'searchable' => 1,
					'class_title' => Array(
						'blt_title'
					) ,
					'unique_keys' => Array(
						'blt_title'
					) ,
					'blt_list' => Array(
						'blt_content' => __('Content', 'drug-search') ,
					) ,
					'req_blt' => Array(
						'blt_title' => Array(
							'msg' => __('Title', 'drug-search')
						) ,
					) ,
				) ,
			);
			update_option($this->option_name . '_ent_list', $ent_list);
			$shc_list['app'] = 'Drug Search';
			$shc_list['has_gmap'] = 0;
			$shc_list['has_bs'] = 0;
			$shc_list['remove_vis'] = 0;
			$shc_list['forms']['drug_search'] = Array(
				'name' => 'drug_search',
				'type' => 'search',
				'ent' => 'emd_drug',
				'page_title' => __('Drug Search', 'drug-search')
			);
			if (!empty($shc_list)) {
				update_option($this->option_name . '_shc_list', $shc_list);
			}
			$attr_list['emd_drug']['emd_drugs_generic_name'] = Array(
				'label' => __('Generic Name', 'drug-search') ,
				'display_type' => 'text',
				'required' => 0,
				'srequired' => 0,
				'filterable' => 1,
				'list_visible' => 1,
				'mid' => 'emd_drug_info_emd_drug_0',
				'type' => 'char',
			);
			$attr_list = apply_filters('emd_ext_attr_list', $attr_list, $this->option_name);
			if (!empty($attr_list)) {
				update_option($this->option_name . '_attr_list', $attr_list);
			}
			update_option($this->option_name . '_glob_init_list', Array());
			$glob_forms_list['drug_search']['captcha'] = 'never-show';
			$glob_forms_list['drug_search']['noaccess_msg'] = 'You are not allowed to access to this area. Please contact the site administrator.';
			$glob_forms_list['drug_search']['login_reg'] = 'none';
			$glob_forms_list['drug_search']['noresult_msg'] = 'Your search returned no results.';
			$glob_forms_list['drug_search']['csrf'] = 0;
			$glob_forms_list['drug_search']['blt_title'] = Array(
				'show' => 1,
				'row' => 1,
				'req' => 0,
				'size' => 12,
				'label' => __('Name', 'drug-search')
			);
			$glob_forms_list['drug_search']['emd_drugs_generic_name'] = Array(
				'show' => 1,
				'row' => 2,
				'req' => 0,
				'size' => 12,
			);
			$glob_forms_list['drug_search']['manufacturer'] = Array(
				'show' => 1,
				'row' => 3,
				'req' => 0,
				'size' => 12,
			);
			$glob_forms_list['drug_search']['pregnancy_category'] = Array(
				'show' => 1,
				'row' => 4,
				'req' => 0,
				'size' => 12,
			);
			$glob_forms_list['drug_search']['availability'] = Array(
				'show' => 1,
				'row' => 5,
				'req' => 0,
				'size' => 12,
			);
			$glob_forms_list['drug_search']['drug_class'] = Array(
				'show' => 1,
				'row' => 6,
				'req' => 0,
				'size' => 12,
			);
			if (!empty($glob_forms_list)) {
				update_option($this->option_name . '_glob_forms_init_list', $glob_forms_list);
				if (get_option($this->option_name . '_glob_forms_list') === false) {
					update_option($this->option_name . '_glob_forms_list', $glob_forms_list);
				}
			}
			$tax_list['emd_drug']['manufacturer'] = Array(
				'archive_view' => 0,
				'label' => __('Manufacturers', 'drug-search') ,
				'default' => '',
				'type' => 'multi',
				'hier' => 0,
				'sortable' => 0,
				'list_visible' => 0,
				'required' => 0,
				'srequired' => 0,
				'rewrite' => 'manufacturer',
				'init_values' => Array(
					Array(
						'name' => __('Wyeth', 'drug-search') ,
						'slug' => sanitize_title('Wyeth')
					) ,
					Array(
						'name' => __('Johnson & Johnson', 'drug-search') ,
						'slug' => sanitize_title('Johnson & Johnson')
					) ,
					Array(
						'name' => __('Novartis', 'drug-search') ,
						'slug' => sanitize_title('Novartis')
					) ,
					Array(
						'name' => __('Roche', 'drug-search') ,
						'slug' => sanitize_title('Roche')
					) ,
					Array(
						'name' => __('Pfizer', 'drug-search') ,
						'slug' => sanitize_title('Pfizer')
					) ,
					Array(
						'name' => __('Sanofi', 'drug-search') ,
						'slug' => sanitize_title('Sanofi')
					) ,
					Array(
						'name' => __('Merck', 'drug-search') ,
						'slug' => sanitize_title('Merck')
					) ,
					Array(
						'name' => __('GlaxoSmithKline', 'drug-search') ,
						'slug' => sanitize_title('GlaxoSmithKline')
					) ,
					Array(
						'name' => __('AstraZeneca', 'drug-search') ,
						'slug' => sanitize_title('AstraZeneca')
					) ,
					Array(
						'name' => __('Bayer', 'drug-search') ,
						'slug' => sanitize_title('Bayer')
					) ,
					Array(
						'name' => __('Gilead', 'drug-search') ,
						'slug' => sanitize_title('Gilead')
					)
				)
			);
			$tax_list['emd_drug']['pregnancy_category'] = Array(
				'archive_view' => 0,
				'label' => __('Pregnancy Categories', 'drug-search') ,
				'default' => '',
				'type' => 'multi',
				'hier' => 0,
				'sortable' => 0,
				'list_visible' => 0,
				'required' => 0,
				'srequired' => 0,
				'rewrite' => 'pregnancy_category',
				'init_values' => Array(
					Array(
						'name' => __('Category N', 'drug-search') ,
						'slug' => sanitize_title('Category N')
					) ,
					Array(
						'name' => __('Category A', 'drug-search') ,
						'slug' => sanitize_title('Category A')
					) ,
					Array(
						'name' => __('Category B', 'drug-search') ,
						'slug' => sanitize_title('Category B')
					) ,
					Array(
						'name' => __('Category C', 'drug-search') ,
						'slug' => sanitize_title('Category C')
					) ,
					Array(
						'name' => __('Category D', 'drug-search') ,
						'slug' => sanitize_title('Category D')
					) ,
					Array(
						'name' => __('Category X', 'drug-search') ,
						'slug' => sanitize_title('Category X')
					)
				)
			);
			$tax_list['emd_drug']['availability'] = Array(
				'archive_view' => 0,
				'label' => __('Availability', 'drug-search') ,
				'default' => '',
				'type' => 'multi',
				'hier' => 0,
				'sortable' => 0,
				'list_visible' => 0,
				'required' => 0,
				'srequired' => 0,
				'rewrite' => 'availability',
				'init_values' => Array(
					Array(
						'name' => __('Rx', 'drug-search') ,
						'slug' => sanitize_title('Rx')
					) ,
					Array(
						'name' => __('OTC', 'drug-search') ,
						'slug' => sanitize_title('OTC')
					)
				)
			);
			$tax_list['emd_drug']['drug_class'] = Array(
				'archive_view' => 0,
				'label' => __('Drug Classes', 'drug-search') ,
				'default' => '',
				'type' => 'multi',
				'hier' => 0,
				'sortable' => 0,
				'list_visible' => 0,
				'required' => 0,
				'srequired' => 0,
				'rewrite' => 'drug_class',
				'init_values' => Array(
					Array(
						'name' => __('Antacids', 'drug-search') ,
						'slug' => sanitize_title('Antacids')
					) ,
					Array(
						'name' => __('Phosphate binders', 'drug-search') ,
						'slug' => sanitize_title('Phosphate binders')
					) ,
					Array(
						'name' => __('Benzodiazepine', 'drug-search') ,
						'slug' => sanitize_title('Benzodiazepine')
					) ,
					Array(
						'name' => __('Cardiac glycoside', 'drug-search') ,
						'slug' => sanitize_title('Cardiac glycoside')
					) ,
					Array(
						'name' => __('Fibrate', 'drug-search') ,
						'slug' => sanitize_title('Fibrate')
					)
				)
			);
			if (!empty($tax_list)) {
				update_option($this->option_name . '_tax_list', $tax_list);
			}
			$emd_activated_plugins = get_option('emd_activated_plugins');
			if (!$emd_activated_plugins) {
				update_option('emd_activated_plugins', Array(
					'drug-search'
				));
			} elseif (!in_array('drug-search', $emd_activated_plugins)) {
				array_push($emd_activated_plugins, 'drug-search');
				update_option('emd_activated_plugins', $emd_activated_plugins);
			}
			//conf parameters for incoming email
			//conf parameters for inline entity
			//conf parameters for calendar
			//action to configure different extension conf parameters for this plugin
			do_action('emd_ext_set_conf', 'drug-search');
		}
		/**
		 * Reset app specific options
		 *
		 * @since WPAS 4.0
		 *
		 */
		private function reset_options() {
			delete_option($this->option_name . '_shc_list');
			do_action('emd_ext_reset_conf', 'drug-search');
		}
		/**
		 * Show admin notices
		 *
		 * @since WPAS 4.0
		 *
		 * @return html
		 */
		public function install_notice() {
			if (current_user_can('manage_options') && get_option($this->option_name . '_setup_pages') == 1) {
				echo "<div id=\"message\" class=\"updated\"><p><strong>" . __('Welcome to Drug Search', 'drug-search') . "</strong></p>
           <p class=\"submit\"><a href=\"" . add_query_arg('setup_drug_search_pages', 'true', admin_url('index.php')) . "\" class=\"button-primary\">" . __('Setup Drug Search Pages', 'drug-search') . "</a> <a class=\"skip button-primary\" href=\"" . add_query_arg('skip_setup_drug_search_pages', 'true', admin_url('index.php')) . "\">" . __('Skip setup', 'drug-search') . "</a></p>
         </div>";
			}
		}
		/**
		 * Setup pages for components and redirect to dashboard
		 *
		 * @since WPAS 4.0
		 *
		 */
		public function setup_pages() {
			if (!is_admin()) {
				return;
			}
			if (!empty($_GET['setup_' . $this->option_name . '_pages'])) {
				$shc_list = get_option($this->option_name . '_shc_list');
				emd_create_install_pages($this->option_name, $shc_list);
				update_option($this->option_name . '_setup_pages', 2);
				wp_redirect(admin_url('admin.php?page=' . $this->option_name . '_settings&drug-search-installed=true'));
				exit;
			}
			if (!empty($_GET['skip_setup_' . $this->option_name . '_pages'])) {
				update_option($this->option_name . '_setup_pages', 2);
				wp_redirect(admin_url('admin.php?page=' . $this->option_name . '_settings'));
				exit;
			}
		}
		public function tinymce_fix($init) {
			global $post;
			$ent_list = get_option($this->option_name . '_ent_list', Array());
			if (!empty($post) && in_array($post->post_type, array_keys($ent_list))) {
				$init['wpautop'] = false;
				$init['indent'] = true;
			}
			return $init;
		}
	}
endif;
return new Drug_Search_Install_Deactivate();
