<?php
/**
 * Entity Class
 *
 * @package DRUG_SEARCH
 * @since WPAS 4.0
 */
if (!defined('ABSPATH')) exit;
/**
 * Emd_Drug Class
 * @since WPAS 4.0
 */
class Emd_Drug extends Emd_Entity {
	protected $post_type = 'emd_drug';
	protected $textdomain = 'drug-search';
	protected $sing_label;
	protected $plural_label;
	protected $menu_entity;
	protected $id;
	/**
	 * Initialize entity class
	 *
	 * @since WPAS 4.0
	 *
	 */
	public function __construct() {
		add_action('init', array(
			$this,
			'set_filters'
		) , 1);
		add_action('admin_init', array(
			$this,
			'set_metabox'
		));
		add_filter('post_updated_messages', array(
			$this,
			'updated_messages'
		));
		$is_adv_filt_ext = apply_filters('emd_adv_filter_on', 0);
		if ($is_adv_filt_ext === 0) {
			add_action('manage_emd_drug_posts_custom_column', array(
				$this,
				'custom_columns'
			) , 10, 2);
			add_filter('manage_emd_drug_posts_columns', array(
				$this,
				'column_headers'
			));
		}
		add_filter('enter_title_here', array(
			$this,
			'change_title_text'
		));
	}
	public function change_title_disable_emd_temp($title, $id) {
		$post = get_post($id);
		if ($this->post_type == $post->post_type && (!empty($this->id) && $this->id == $id)) {
			return '';
		}
		return $title;
	}
	/**
	 * Get column header list in admin list pages
	 * @since WPAS 4.0
	 *
	 * @param array $columns
	 *
	 * @return array $columns
	 */
	public function column_headers($columns) {
		$ent_list = get_option(str_replace("-", "_", $this->textdomain) . '_ent_list');
		if (!empty($ent_list[$this->post_type]['featured_img'])) {
			$columns['featured_img'] = __('Featured Image', $this->textdomain);
		}
		foreach ($this->boxes as $mybox) {
			foreach ($mybox['fields'] as $fkey => $mybox_field) {
				if (!in_array($fkey, Array(
					'wpas_form_name',
					'wpas_form_submitted_by',
					'wpas_form_submitted_ip'
				)) && !in_array($mybox_field['type'], Array(
					'textarea',
					'wysiwyg'
				)) && $mybox_field['list_visible'] == 1) {
					$columns[$fkey] = $mybox_field['name'];
				}
			}
		}
		$taxonomies = get_object_taxonomies($this->post_type, 'objects');
		if (!empty($taxonomies)) {
			$tax_list = get_option(str_replace("-", "_", $this->textdomain) . '_tax_list');
			foreach ($taxonomies as $taxonomy) {
				if (!empty($tax_list[$this->post_type][$taxonomy->name]) && $tax_list[$this->post_type][$taxonomy->name]['list_visible'] == 1) {
					$columns[$taxonomy->name] = $taxonomy->label;
				}
			}
		}
		$rel_list = get_option(str_replace("-", "_", $this->textdomain) . '_rel_list');
		if (!empty($rel_list)) {
			foreach ($rel_list as $krel => $rel) {
				if ($rel['from'] == $this->post_type && in_array($rel['show'], Array(
					'any',
					'from'
				))) {
					$columns[$krel] = $rel['from_title'];
				} elseif ($rel['to'] == $this->post_type && in_array($rel['show'], Array(
					'any',
					'to'
				))) {
					$columns[$krel] = $rel['to_title'];
				}
			}
		}
		return $columns;
	}
	/**
	 * Get custom column values in admin list pages
	 * @since WPAS 4.0
	 *
	 * @param int $column_id
	 * @param int $post_id
	 *
	 * @return string $value
	 */
	public function custom_columns($column_id, $post_id) {
		if (taxonomy_exists($column_id) == true) {
			$terms = get_the_terms($post_id, $column_id);
			$ret = array();
			if (!empty($terms)) {
				foreach ($terms as $term) {
					$url = add_query_arg(array(
						'post_type' => $this->post_type,
						'term' => $term->slug,
						'taxonomy' => $column_id
					) , admin_url('edit.php'));
					$a_class = preg_replace('/^emd_/', '', $this->post_type);
					$ret[] = sprintf('<a href="%s"  class="' . $a_class . '-tax ' . $term->slug . '">%s</a>', $url, $term->name);
				}
			}
			echo implode(', ', $ret);
			return;
		}
		$rel_list = get_option(str_replace("-", "_", $this->textdomain) . '_rel_list');
		if (!empty($rel_list) && !empty($rel_list[$column_id])) {
			$rel_arr = $rel_list[$column_id];
			if ($rel_arr['from'] == $this->post_type) {
				$other_ptype = $rel_arr['to'];
			} elseif ($rel_arr['to'] == $this->post_type) {
				$other_ptype = $rel_arr['from'];
			}
			$column_id = str_replace('rel_', '', $column_id);
			if (function_exists('p2p_type') && p2p_type($column_id)) {
				$rel_args = apply_filters('emd_ext_p2p_add_query_vars', array(
					'posts_per_page' => - 1
				) , Array(
					$other_ptype
				));
				$connected = p2p_type($column_id)->get_connected($post_id, $rel_args);
				$ptype_obj = get_post_type_object($this->post_type);
				$edit_cap = $ptype_obj->cap->edit_posts;
				$ret = array();
				if (empty($connected->posts)) return '&ndash;';
				foreach ($connected->posts as $myrelpost) {
					$rel_title = get_the_title($myrelpost->ID);
					$rel_title = apply_filters('emd_ext_p2p_connect_title', $rel_title, $myrelpost, '');
					$url = get_permalink($myrelpost->ID);
					$url = apply_filters('emd_ext_connected_ptype_url', $url, $myrelpost, $edit_cap);
					$ret[] = sprintf('<a href="%s" title="%s" target="_blank">%s</a>', $url, $rel_title, $rel_title);
				}
				echo implode(', ', $ret);
				return;
			}
		}
		$value = get_post_meta($post_id, $column_id, true);
		$type = "";
		foreach ($this->boxes as $mybox) {
			foreach ($mybox['fields'] as $fkey => $mybox_field) {
				if ($fkey == $column_id) {
					$type = $mybox_field['type'];
					break;
				}
			}
		}
		if ($column_id == 'featured_img') {
			$type = 'featured_img';
		}
		switch ($type) {
			case 'featured_img':
				$thumb_url = wp_get_attachment_image_src(get_post_thumbnail_id($post_id) , 'thumbnail');
				if (!empty($thumb_url)) {
					$value = "<img style='max-width:100%;height:auto;' src='" . $thumb_url[0] . "' >";
				}
			break;
			case 'plupload_image':
			case 'image':
			case 'thickbox_image':
				$image_list = emd_mb_meta($column_id, 'type=image');
				$value = "";
				if (!empty($image_list)) {
					$myimage = current($image_list);
					$value = "<img style='max-width:100%;height:auto;' src='" . $myimage['url'] . "' >";
				}
			break;
			case 'user':
			case 'user-adv':
				$user_id = emd_mb_meta($column_id);
				if (!empty($user_id)) {
					$user_info = get_userdata($user_id);
					$value = $user_info->display_name;
				}
			break;
			case 'file':
				$file_list = emd_mb_meta($column_id, 'type=file');
				if (!empty($file_list)) {
					$value = "";
					foreach ($file_list as $myfile) {
						$fsrc = wp_mime_type_icon($myfile['ID']);
						$value.= "<a style='margin:5px;' href='" . $myfile['url'] . "' target='_blank'><img src='" . $fsrc . "' title='" . $myfile['name'] . "' width='20' /></a>";
					}
				}
			break;
			case 'radio':
			case 'checkbox_list':
			case 'select':
			case 'select_advanced':
				$value = emd_get_attr_val(str_replace("-", "_", $this->textdomain) , $post_id, $this->post_type, $column_id);
			break;
			case 'checkbox':
				if ($value == 1) {
					$value = '<span class="dashicons dashicons-yes"></span>';
				} elseif ($value == 0) {
					$value = '<span class="dashicons dashicons-no-alt"></span>';
				}
			break;
			case 'rating':
				$value = apply_filters('emd_get_rating_value', $value, Array(
					'meta' => $column_id
				) , $post_id);
			break;
		}
		if (is_array($value)) {
			$value = "<div class='clonelink'>" . implode("</div><div class='clonelink'>", $value) . "</div>";
		}
		echo $value;
	}
	/**
	 * Register post type and taxonomies and set initial values for taxs
	 *
	 * @since WPAS 4.0
	 *
	 */
	public static function register() {
		$labels = array(
			'name' => __('Drugs', 'drug-search') ,
			'singular_name' => __('Drug', 'drug-search') ,
			'add_new' => __('Add New', 'drug-search') ,
			'add_new_item' => __('Add New Drug', 'drug-search') ,
			'edit_item' => __('Edit Drug', 'drug-search') ,
			'new_item' => __('New Drug', 'drug-search') ,
			'all_items' => __('All Drugs', 'drug-search') ,
			'view_item' => __('View Drug', 'drug-search') ,
			'search_items' => __('Search Drugs', 'drug-search') ,
			'not_found' => __('No Drugs Found', 'drug-search') ,
			'not_found_in_trash' => __('No Drugs Found In Trash', 'drug-search') ,
			'menu_name' => __('Drugs', 'drug-search') ,
		);
		$ent_map_list = get_option('drug_search_ent_map_list', Array());
		$myrole = emd_get_curr_usr_role('drug_search');
		if (!empty($ent_map_list['emd_drug']['rewrite'])) {
			$rewrite = $ent_map_list['emd_drug']['rewrite'];
		} else {
			$rewrite = 'emd_drug';
		}
		$supports = Array();
		if (empty($ent_map_list['emd_drug']['attrs']['blt_title']) || $ent_map_list['emd_drug']['attrs']['blt_title'] != 'hide') {
			if (empty($ent_map_list['emd_drug']['edit_attrs'])) {
				$supports[] = 'title';
			} elseif ($myrole == 'administrator') {
				$supports[] = 'title';
			} elseif ($myrole != 'administrator' && !empty($ent_map_list['emd_drug']['edit_attrs'][$myrole]['blt_title']) && $ent_map_list['emd_drug']['edit_attrs'][$myrole]['blt_title'] == 'edit') {
				$supports[] = 'title';
			}
		}
		if (empty($ent_map_list['emd_drug']['attrs']['blt_content']) || $ent_map_list['emd_drug']['attrs']['blt_content'] != 'hide') {
			if (empty($ent_map_list['emd_drug']['edit_attrs'])) {
				$supports[] = 'editor';
			} elseif ($myrole == 'administrator') {
				$supports[] = 'editor';
			} elseif ($myrole != 'administrator' && !empty($ent_map_list['emd_drug']['edit_attrs'][$myrole]['blt_content']) && $ent_map_list['emd_drug']['edit_attrs'][$myrole]['blt_content'] == 'edit') {
				$supports[] = 'editor';
			}
		}
		if (empty($ent_map_list['emd_drug']['attrs']['featured_img']) || $ent_map_list['emd_drug']['attrs']['featured_img'] != 'hide') {
			if (empty($ent_map_list['emd_drug']['edit_attrs'])) {
				$supports[] = 'thumbnail';
			} elseif ($myrole == 'administrator') {
				$supports[] = 'thumbnail';
			} elseif ($myrole != 'administrator' && !empty($ent_map_list['emd_drug']['edit_attrs'][$myrole]['featured_img']) && $ent_map_list['emd_drug']['edit_attrs'][$myrole]['featured_img'] == 'edit') {
				$supports[] = 'thumbnail';
			}
		}
		register_post_type('emd_drug', array(
			'labels' => $labels,
			'public' => true,
			'publicly_queryable' => true,
			'show_ui' => true,
			'description' => __('', 'drug-search') ,
			'show_in_menu' => true,
			'menu_position' => 6,
			'has_archive' => true,
			'exclude_from_search' => false,
			'rewrite' => array(
				'slug' => $rewrite
			) ,
			'can_export' => true,
			'show_in_rest' => false,
			'hierarchical' => false,
			'map_meta_cap' => 'false',
			'taxonomies' => array() ,
			'capability_type' => 'post',
			'supports' => $supports,
		));
		$tax_settings = get_option('drug_search_tax_settings', Array());
		$myrole = emd_get_curr_usr_role('drug_search');
		$drug_class_nohr_labels = array(
			'name' => __('Drug Classes', 'drug-search') ,
			'singular_name' => __('Drug Class', 'drug-search') ,
			'search_items' => __('Search Drug Classes', 'drug-search') ,
			'popular_items' => __('Popular Drug Classes', 'drug-search') ,
			'all_items' => __('All', 'drug-search') ,
			'parent_item' => null,
			'parent_item_colon' => null,
			'edit_item' => __('Edit Drug Class', 'drug-search') ,
			'update_item' => __('Update Drug Class', 'drug-search') ,
			'add_new_item' => __('Add New Drug Class', 'drug-search') ,
			'new_item_name' => __('Add New Drug Class Name', 'drug-search') ,
			'separate_items_with_commas' => __('Seperate Drug Classes with commas', 'drug-search') ,
			'add_or_remove_items' => __('Add or Remove Drug Classes', 'drug-search') ,
			'choose_from_most_used' => __('Choose from the most used Drug Classes', 'drug-search') ,
			'menu_name' => __('Drug Classes', 'drug-search') ,
		);
		if (empty($tax_settings['drug_class']['hide']) || (!empty($tax_settings['drug_class']['hide']) && $tax_settings['drug_class']['hide'] != 'hide')) {
			if (!empty($tax_settings['drug_class']['rewrite'])) {
				$rewrite = $tax_settings['drug_class']['rewrite'];
			} else {
				$rewrite = 'drug_class';
			}
			$targs = array(
				'hierarchical' => false,
				'labels' => $drug_class_nohr_labels,
				'public' => true,
				'show_ui' => true,
				'show_in_nav_menus' => true,
				'show_in_menu' => true,
				'show_tagcloud' => true,
				'update_count_callback' => '_update_post_term_count',
				'query_var' => true,
				'rewrite' => array(
					'slug' => $rewrite,
				) ,
				'show_in_rest' => false,
				'capabilities' => array(
					'manage_terms' => 'manage_drug_class',
					'edit_terms' => 'edit_drug_class',
					'delete_terms' => 'delete_drug_class',
					'assign_terms' => 'assign_drug_class'
				) ,
			);
			if ($myrole != 'administrator' && !empty($tax_settings['drug_class']['edit'][$myrole]) && $tax_settings['drug_class']['edit'][$myrole] != 'edit') {
				$targs['meta_box_cb'] = false;
			}
			register_taxonomy('drug_class', array(
				'emd_drug'
			) , $targs);
		}
		$availability_nohr_labels = array(
			'name' => __('Availability', 'drug-search') ,
			'singular_name' => __('Availability', 'drug-search') ,
			'search_items' => __('Search Availability', 'drug-search') ,
			'popular_items' => __('Popular Availability', 'drug-search') ,
			'all_items' => __('All', 'drug-search') ,
			'parent_item' => null,
			'parent_item_colon' => null,
			'edit_item' => __('Edit Availability', 'drug-search') ,
			'update_item' => __('Update Availability', 'drug-search') ,
			'add_new_item' => __('Add New Availability', 'drug-search') ,
			'new_item_name' => __('Add New Availability Name', 'drug-search') ,
			'separate_items_with_commas' => __('Seperate Availability with commas', 'drug-search') ,
			'add_or_remove_items' => __('Add or Remove Availability', 'drug-search') ,
			'choose_from_most_used' => __('Choose from the most used Availability', 'drug-search') ,
			'menu_name' => __('Availability', 'drug-search') ,
		);
		if (empty($tax_settings['availability']['hide']) || (!empty($tax_settings['availability']['hide']) && $tax_settings['availability']['hide'] != 'hide')) {
			if (!empty($tax_settings['availability']['rewrite'])) {
				$rewrite = $tax_settings['availability']['rewrite'];
			} else {
				$rewrite = 'availability';
			}
			$targs = array(
				'hierarchical' => false,
				'labels' => $availability_nohr_labels,
				'public' => true,
				'show_ui' => true,
				'show_in_nav_menus' => true,
				'show_in_menu' => true,
				'show_tagcloud' => true,
				'update_count_callback' => '_update_post_term_count',
				'query_var' => true,
				'rewrite' => array(
					'slug' => $rewrite,
				) ,
				'show_in_rest' => false,
				'capabilities' => array(
					'manage_terms' => 'manage_availability',
					'edit_terms' => 'edit_availability',
					'delete_terms' => 'delete_availability',
					'assign_terms' => 'assign_availability'
				) ,
			);
			if ($myrole != 'administrator' && !empty($tax_settings['availability']['edit'][$myrole]) && $tax_settings['availability']['edit'][$myrole] != 'edit') {
				$targs['meta_box_cb'] = false;
			}
			register_taxonomy('availability', array(
				'emd_drug'
			) , $targs);
		}
		$manufacturer_nohr_labels = array(
			'name' => __('Manufacturers', 'drug-search') ,
			'singular_name' => __('Manufacturer', 'drug-search') ,
			'search_items' => __('Search Manufacturers', 'drug-search') ,
			'popular_items' => __('Popular Manufacturers', 'drug-search') ,
			'all_items' => __('All', 'drug-search') ,
			'parent_item' => null,
			'parent_item_colon' => null,
			'edit_item' => __('Edit Manufacturer', 'drug-search') ,
			'update_item' => __('Update Manufacturer', 'drug-search') ,
			'add_new_item' => __('Add New Manufacturer', 'drug-search') ,
			'new_item_name' => __('Add New Manufacturer Name', 'drug-search') ,
			'separate_items_with_commas' => __('Seperate Manufacturers with commas', 'drug-search') ,
			'add_or_remove_items' => __('Add or Remove Manufacturers', 'drug-search') ,
			'choose_from_most_used' => __('Choose from the most used Manufacturers', 'drug-search') ,
			'menu_name' => __('Manufacturers', 'drug-search') ,
		);
		if (empty($tax_settings['manufacturer']['hide']) || (!empty($tax_settings['manufacturer']['hide']) && $tax_settings['manufacturer']['hide'] != 'hide')) {
			if (!empty($tax_settings['manufacturer']['rewrite'])) {
				$rewrite = $tax_settings['manufacturer']['rewrite'];
			} else {
				$rewrite = 'manufacturer';
			}
			$targs = array(
				'hierarchical' => false,
				'labels' => $manufacturer_nohr_labels,
				'public' => true,
				'show_ui' => true,
				'show_in_nav_menus' => true,
				'show_in_menu' => true,
				'show_tagcloud' => true,
				'update_count_callback' => '_update_post_term_count',
				'query_var' => true,
				'rewrite' => array(
					'slug' => $rewrite,
				) ,
				'show_in_rest' => false,
				'capabilities' => array(
					'manage_terms' => 'manage_manufacturer',
					'edit_terms' => 'edit_manufacturer',
					'delete_terms' => 'delete_manufacturer',
					'assign_terms' => 'assign_manufacturer'
				) ,
			);
			if ($myrole != 'administrator' && !empty($tax_settings['manufacturer']['edit'][$myrole]) && $tax_settings['manufacturer']['edit'][$myrole] != 'edit') {
				$targs['meta_box_cb'] = false;
			}
			register_taxonomy('manufacturer', array(
				'emd_drug'
			) , $targs);
		}
		$pregnancy_category_nohr_labels = array(
			'name' => __('Pregnancy Categories', 'drug-search') ,
			'singular_name' => __('Pregnancy Category', 'drug-search') ,
			'search_items' => __('Search Pregnancy Categories', 'drug-search') ,
			'popular_items' => __('Popular Pregnancy Categories', 'drug-search') ,
			'all_items' => __('All', 'drug-search') ,
			'parent_item' => null,
			'parent_item_colon' => null,
			'edit_item' => __('Edit Pregnancy Category', 'drug-search') ,
			'update_item' => __('Update Pregnancy Category', 'drug-search') ,
			'add_new_item' => __('Add New Pregnancy Category', 'drug-search') ,
			'new_item_name' => __('Add New Pregnancy Category Name', 'drug-search') ,
			'separate_items_with_commas' => __('Seperate Pregnancy Categories with commas', 'drug-search') ,
			'add_or_remove_items' => __('Add or Remove Pregnancy Categories', 'drug-search') ,
			'choose_from_most_used' => __('Choose from the most used Pregnancy Categories', 'drug-search') ,
			'menu_name' => __('Pregnancy Categories', 'drug-search') ,
		);
		if (empty($tax_settings['pregnancy_category']['hide']) || (!empty($tax_settings['pregnancy_category']['hide']) && $tax_settings['pregnancy_category']['hide'] != 'hide')) {
			if (!empty($tax_settings['pregnancy_category']['rewrite'])) {
				$rewrite = $tax_settings['pregnancy_category']['rewrite'];
			} else {
				$rewrite = 'pregnancy_category';
			}
			$targs = array(
				'hierarchical' => false,
				'labels' => $pregnancy_category_nohr_labels,
				'public' => true,
				'show_ui' => true,
				'show_in_nav_menus' => true,
				'show_in_menu' => true,
				'show_tagcloud' => true,
				'update_count_callback' => '_update_post_term_count',
				'query_var' => true,
				'rewrite' => array(
					'slug' => $rewrite,
				) ,
				'show_in_rest' => false,
				'capabilities' => array(
					'manage_terms' => 'manage_pregnancy_category',
					'edit_terms' => 'edit_pregnancy_category',
					'delete_terms' => 'delete_pregnancy_category',
					'assign_terms' => 'assign_pregnancy_category'
				) ,
			);
			if ($myrole != 'administrator' && !empty($tax_settings['pregnancy_category']['edit'][$myrole]) && $tax_settings['pregnancy_category']['edit'][$myrole] != 'edit') {
				$targs['meta_box_cb'] = false;
			}
			register_taxonomy('pregnancy_category', array(
				'emd_drug'
			) , $targs);
		}
		$tax_list = get_option('drug_search_tax_list');
		$init_tax = get_option('drug_search_init_tax', Array());
		if (!empty($tax_list['emd_drug'])) {
			foreach ($tax_list['emd_drug'] as $keytax => $mytax) {
				if (!empty($mytax['init_values']) && (empty($init_tax['emd_drug']) || (!empty($init_tax['emd_drug']) && !in_array($keytax, $init_tax['emd_drug'])))) {
					$set_tax_terms = Array();
					foreach ($mytax['init_values'] as $myinit) {
						$set_tax_terms[] = $myinit;
					}
					self::set_taxonomy_init($set_tax_terms, $keytax);
					$init_tax['emd_drug'][] = $keytax;
				}
			}
			update_option('drug_search_init_tax', $init_tax);
		}
	}
	/**
	 * Set metabox fields,labels,filters, comments, relationships if exists
	 *
	 * @since WPAS 4.0
	 *
	 */
	public function set_filters() {
		do_action('emd_ext_class_init', $this);
		$search_args = Array();
		$filter_args = Array();
		$this->sing_label = __('Drug', 'drug-search');
		$this->plural_label = __('Drugs', 'drug-search');
		$this->menu_entity = 'emd_drug';
		$this->boxes['emd_drug_info_emd_drug_0'] = array(
			'id' => 'emd_drug_info_emd_drug_0',
			'title' => __('Drug Info', 'drug-search') ,
			'app_name' => 'drug_search',
			'pages' => array(
				'emd_drug'
			) ,
			'context' => 'normal',
		);
		list($search_args, $filter_args) = $this->set_args_boxes();
		if (!post_type_exists($this->post_type) || in_array($this->post_type, Array(
			'post',
			'page'
		))) {
			self::register();
		}
		do_action('emd_set_adv_filtering', $this->post_type, $search_args, $this->boxes, $filter_args, $this->textdomain, $this->plural_label);
		$ent_map_list = get_option(str_replace('-', '_', $this->textdomain) . '_ent_map_list');
	}
	/**
	 * Initialize metaboxes
	 * @since WPAS 4.5
	 *
	 */
	public function set_metabox() {
		if (class_exists('EMD_Meta_Box') && is_array($this->boxes)) {
			foreach ($this->boxes as $meta_box) {
				new EMD_Meta_Box($meta_box);
			}
		}
	}
	/**
	 * Change content for created frontend views
	 * @since WPAS 4.0
	 * @param string $content
	 *
	 * @return string $content
	 */
	public function change_content($content) {
		global $post;
		$layout = "";
		$this->id = $post->ID;
		$tools = get_option('drug_search_tools');
		if (!empty($tools['disable_emd_templates'])) {
			add_filter('the_title', array(
				$this,
				'change_title_disable_emd_temp'
			) , 10, 2);
		}
		if (get_post_type() == $this->post_type && is_single()) {
			ob_start();
			emd_get_template_part($this->textdomain, 'single', 'emd-drug');
			$layout = ob_get_clean();
		}
		if ($layout != "") {
			$content = $layout;
		}
		if (!empty($tools['disable_emd_templates'])) {
			remove_filter('the_title', array(
				$this,
				'change_title_disable_emd_temp'
			) , 10, 2);
		}
		return $content;
	}
	/**
	 * Add operations and add new submenu hook
	 * @since WPAS 4.4
	 */
	public function add_menu_link() {
		add_submenu_page(null, __('Operations', 'drug-search') , __('Operations', 'drug-search') , 'manage_operations_emd_drugs', 'operations_emd_drug', array(
			$this,
			'get_operations'
		));
	}
	/**
	 * Display operations page
	 * @since WPAS 4.0
	 */
	public function get_operations() {
		if (current_user_can('manage_operations_emd_drugs')) {
			$myapp = str_replace("-", "_", $this->textdomain);
			do_action('emd_operations_entity', $this->post_type, $this->plural_label, $this->sing_label, $myapp, $this->menu_entity);
		}
	}
	public function change_title_text($title) {
		$screen = get_current_screen();
		if ($this->post_type == $screen->post_type) {
			$title = __('Enter Name here', 'drug-search');
		}
		return $title;
	}
}
new Emd_Drug;
