<?php
/**
 * Setup and Process submit and search forms
 * @package DRUG_SEARCH
 * @since WPAS 4.0
 */
if (!defined('ABSPATH')) exit;
if (is_admin()) {
	add_action('wp_ajax_nopriv_emd_check_unique', 'emd_check_unique');
}
if (!is_admin() || (defined('DOING_AJAX') && DOING_AJAX)) {
	add_filter('posts_where', 'emd_builtin_posts_where', 10, 2);
}
add_action('init', 'drug_search_form_shortcodes', -2);
/**
 * Start session and setup upload idr and current user id
 * @since WPAS 4.0
 *
 */
function drug_search_form_shortcodes() {
	global $file_upload_dir;
	$upload_dir = wp_upload_dir();
	$file_upload_dir = $upload_dir['basedir'];
	if (!empty($_POST['emd_action'])) {
		if ($_POST['emd_action'] == 'drug_search_user_login' && wp_verify_nonce($_POST['emd_login_nonce'], 'emd-login-nonce')) {
			emd_process_login($_POST, 'drug_search');
		} elseif ($_POST['emd_action'] == 'drug_search_user_register' && wp_verify_nonce($_POST['emd_register_nonce'], 'emd-register-nonce')) {
			emd_process_register($_POST, 'drug_search');
		}
	}
}
add_shortcode('drug_search', 'drug_search_process_drug_search');
/**
 * Set each form field(attr,tax and rels) and render form
 *
 * @since WPAS 4.0
 *
 * @return object $form
 */
function drug_search_set_drug_search($atts) {
	global $file_upload_dir;
	$show_captcha = 0;
	$form_variables = get_option('drug_search_glob_forms_list');
	$form_init_variables = get_option('drug_search_glob_forms_init_list');
	if (!empty($atts['set'])) {
		$set_arrs = emd_parse_set_filter($atts['set']);
	}
	if (!empty($form_variables['drug_search']['captcha'])) {
		switch ($form_variables['drug_search']['captcha']) {
			case 'never-show':
				$show_captcha = 0;
			break;
			case 'show-always':
				$show_captcha = 1;
			break;
			case 'show-to-visitors':
				if (is_user_logged_in()) {
					$show_captcha = 0;
				} else {
					$show_captcha = 1;
				}
			break;
		}
	}
	$req_hide_vars = emd_get_form_req_hide_vars('drug_search', 'drug_search');
	$ent_map_list = get_option('drug_search_ent_map_list');
	$fname_id = 'drug_search';
	if (!empty($atts['id'])) {
		$fname_id = 'drug_search_' . $atts['id'];
	}
	$form = new Zebra_Form($fname_id, 0, 'POST', '', array(
		'class' => 'drug_search form-container wpas-form wpas-form-stacked',
		'session_obj' => DRUG_SEARCH()->session
	));
	$csrf_storage_method = (isset($form_variables['drug_search']['csrf']) ? $form_variables['drug_search']['csrf'] : $form_init_variables['drug_search']['csrf']);
	if ($csrf_storage_method == 0) {
		$form->form_properties['csrf_storage_method'] = false;
	}
	if (!in_array('blt_title', $req_hide_vars['hide'])) {
		//text
		$form->add('label', 'label_blt_title', 'blt_title', __('Name', 'drug-search') , array(
			'class' => 'control-label'
		));
		$attrs = array(
			'class' => 'input-md form-control',
			'placeholder' => __('Name', 'drug-search')
		);
		if (!empty($_GET['blt_title'])) {
			$attrs['value'] = sanitize_text_field($_GET['blt_title']);
		} elseif (!empty($set_arrs['attr']['blt_title'])) {
			$attrs['value'] = $set_arrs['attr']['blt_title'];
		}
		$obj = $form->add('text', 'blt_title', '', $attrs);
		$zrule = Array();
		if (in_array('blt_title', $req_hide_vars['req'])) {
			$zrule = array_merge($zrule, Array(
				'required' => array(
					'error',
					__('Name is required', 'drug-search')
				)
			));
		}
		$obj->set_rule($zrule);
	}
	if (!in_array('emd_drugs_generic_name', $req_hide_vars['hide'])) {
		//text
		$form->add('label', 'label_emd_drugs_generic_name', 'emd_drugs_generic_name', __('Generic Name', 'drug-search') , array(
			'class' => 'control-label'
		));
		$attrs = array(
			'class' => 'input-md form-control',
			'placeholder' => __('Generic Name', 'drug-search')
		);
		if (!empty($_GET['emd_drugs_generic_name'])) {
			$attrs['value'] = sanitize_text_field($_GET['emd_drugs_generic_name']);
		} elseif (!empty($set_arrs['attr']['emd_drugs_generic_name'])) {
			$attrs['value'] = $set_arrs['attr']['emd_drugs_generic_name'];
		}
		$obj = $form->add('text', 'emd_drugs_generic_name', '', $attrs);
		$zrule = Array(
			'dependencies' => array() ,
		);
		if (in_array('emd_drugs_generic_name', $req_hide_vars['req'])) {
			$zrule = array_merge($zrule, Array(
				'required' => array(
					'error',
					__('Generic Name is required', 'drug-search')
				)
			));
		}
		$obj->set_rule($zrule);
	}
	if (!in_array('manufacturer', $req_hide_vars['hide'])) {
		$form->add('label', 'label_manufacturer', 'manufacturer', __('Manufacturer', 'drug-search') , array(
			'class' => 'control-label'
		));
		$attrs = array(
			'multiple' => 'multiple',
			'class' => 'input-md'
		);
		if (!empty($_GET['manufacturer'])) {
			$attrs['value'] = sanitize_text_field($_GET['manufacturer']);
		} elseif (!empty($set_arrs['tax']['manufacturer'])) {
			$attrs['value'] = $set_arrs['tax']['manufacturer'];
		}
		$obj = $form->add('selectadv', 'manufacturer[]', '', $attrs, '', '{"allowClear":true,"placeholder":"' . __("Please Select", "drug-search") . '","placeholderOption":"first"}');
		//get taxonomy values
		$txn_arr = Array();
		$txn_obj = get_terms('manufacturer', array(
			'hide_empty' => 0
		));
		foreach ($txn_obj as $txn) {
			$txn_arr[$txn->slug] = $txn->name;
		}
		$obj->add_options($txn_arr);
		$zrule = Array(
			'dependencies' => array() ,
		);
		if (in_array('manufacturer', $req_hide_vars['req'])) {
			$zrule = array_merge($zrule, Array(
				'required' => array(
					'error',
					__('Manufacturer is required!', 'drug-search')
				)
			));
		}
		$obj->set_rule($zrule);
	}
	if (!in_array('pregnancy_category', $req_hide_vars['hide'])) {
		$form->add('label', 'label_pregnancy_category', 'pregnancy_category', __('Pregnancy Category', 'drug-search') , array(
			'class' => 'control-label'
		));
		$attrs = array(
			'multiple' => 'multiple',
			'class' => 'input-md'
		);
		if (!empty($_GET['pregnancy_category'])) {
			$attrs['value'] = sanitize_text_field($_GET['pregnancy_category']);
		} elseif (!empty($set_arrs['tax']['pregnancy_category'])) {
			$attrs['value'] = $set_arrs['tax']['pregnancy_category'];
		}
		$obj = $form->add('selectadv', 'pregnancy_category[]', '', $attrs, '', '{"allowClear":true,"placeholder":"' . __("Please Select", "drug-search") . '","placeholderOption":"first"}');
		//get taxonomy values
		$txn_arr = Array();
		$txn_obj = get_terms('pregnancy_category', array(
			'hide_empty' => 0
		));
		foreach ($txn_obj as $txn) {
			$txn_arr[$txn->slug] = $txn->name;
		}
		$obj->add_options($txn_arr);
		$zrule = Array(
			'dependencies' => array() ,
		);
		if (in_array('pregnancy_category', $req_hide_vars['req'])) {
			$zrule = array_merge($zrule, Array(
				'required' => array(
					'error',
					__('Pregnancy Category is required!', 'drug-search')
				)
			));
		}
		$obj->set_rule($zrule);
	}
	if (!in_array('availability', $req_hide_vars['hide'])) {
		$form->add('label', 'label_availability', 'availability', __('Availability', 'drug-search') , array(
			'class' => 'control-label'
		));
		$attrs = array(
			'multiple' => 'multiple',
			'class' => 'input-md'
		);
		if (!empty($_GET['availability'])) {
			$attrs['value'] = sanitize_text_field($_GET['availability']);
		} elseif (!empty($set_arrs['tax']['availability'])) {
			$attrs['value'] = $set_arrs['tax']['availability'];
		}
		$obj = $form->add('selectadv', 'availability[]', '', $attrs, '', '{"allowClear":true,"placeholder":"' . __("Please Select", "drug-search") . '","placeholderOption":"first"}');
		//get taxonomy values
		$txn_arr = Array();
		$txn_obj = get_terms('availability', array(
			'hide_empty' => 0
		));
		foreach ($txn_obj as $txn) {
			$txn_arr[$txn->slug] = $txn->name;
		}
		$obj->add_options($txn_arr);
		$zrule = Array(
			'dependencies' => array() ,
		);
		if (in_array('availability', $req_hide_vars['req'])) {
			$zrule = array_merge($zrule, Array(
				'required' => array(
					'error',
					__('Availability is required!', 'drug-search')
				)
			));
		}
		$obj->set_rule($zrule);
	}
	if (!in_array('drug_class', $req_hide_vars['hide'])) {
		$form->add('label', 'label_drug_class', 'drug_class', __('Drug Class', 'drug-search') , array(
			'class' => 'control-label'
		));
		$attrs = array(
			'multiple' => 'multiple',
			'class' => 'input-md'
		);
		if (!empty($_GET['drug_class'])) {
			$attrs['value'] = sanitize_text_field($_GET['drug_class']);
		} elseif (!empty($set_arrs['tax']['drug_class'])) {
			$attrs['value'] = $set_arrs['tax']['drug_class'];
		}
		$obj = $form->add('selectadv', 'drug_class[]', '', $attrs, '', '{"allowClear":true,"placeholder":"' . __("Please Select", "drug-search") . '","placeholderOption":"first"}');
		//get taxonomy values
		$txn_arr = Array();
		$txn_obj = get_terms('drug_class', array(
			'hide_empty' => 0
		));
		foreach ($txn_obj as $txn) {
			$txn_arr[$txn->slug] = $txn->name;
		}
		$obj->add_options($txn_arr);
		$zrule = Array(
			'dependencies' => array() ,
		);
		if (in_array('drug_class', $req_hide_vars['req'])) {
			$zrule = array_merge($zrule, Array(
				'required' => array(
					'error',
					__('Drug Class is required!', 'drug-search')
				)
			));
		}
		$obj->set_rule($zrule);
	}
	$form->assign('show_captcha', $show_captcha);
	if ($show_captcha == 1) {
		//Captcha
		$form->add('captcha', 'captcha_image', 'captcha_code', '', '<span style="font-weight:bold;" class="refresh-txt">Refresh</span>', 'refcapt');
		$form->add('label', 'label_captcha_code', 'captcha_code', __('Please enter the characters with black color.', 'drug-search'));
		$obj = $form->add('text', 'captcha_code', '', array(
			'placeholder' => __('Code', 'drug-search')
		));
		$obj->set_rule(array(
			'required' => array(
				'error',
				__('Captcha is required', 'drug-search')
			) ,
			'captcha' => array(
				'error',
				__('Characters from captcha image entered incorrectly!', 'drug-search')
			)
		));
	}
	$form->add('submit', 'singlebutton_drug_search', '' . __('Search', 'drug-search') . ' ', array(
		'class' => 'wpas-button wpas-juibutton-secondary   col-md-12 col-lg-12 col-xs-12 col-sm-12'
	));
	return $form;
}
/**
 * Process each form and show error or success
 *
 * @since WPAS 4.0
 *
 * @return html
 */
function drug_search_process_drug_search($atts) {
	$show_form = 1;
	$access_views = get_option('drug_search_access_views', Array());
	if (!current_user_can('view_drug_search') && !empty($access_views['forms']) && in_array('drug_search', $access_views['forms'])) {
		$show_form = 0;
	}
	$form_init_variables = get_option('drug_search_glob_forms_init_list');
	$form_variables = get_option('drug_search_glob_forms_list');
	if ($show_form == 1) {
		if (!empty($form_init_variables['drug_search']['login_reg'])) {
			$show_login_register = (isset($form_variables['drug_search']['login_reg']) ? $form_variables['drug_search']['login_reg'] : $form_init_variables['drug_search']['login_reg']);
			if (!is_user_logged_in() && $show_login_register != 'none') {
				do_action('emd_show_login_register_forms', 'drug_search', 'drug_search', $show_login_register);
				return;
			}
		}
		wp_enqueue_script('wpas-jvalidate-js');
		wp_enqueue_style('wpasui');
		wp_enqueue_style('drug-search-forms');
		wp_enqueue_script('drug-search-forms-js');
		wp_enqueue_style('drug-search-allview-css');
		wp_enqueue_style('emd-pagination');
		drug_search_enq_custom_css_js();
		do_action('emd_ext_form_enq', 'drug_search', 'drug_search');
		$noresult_msg = (isset($form_variables['drug_search']['noresult_msg']) ? $form_variables['drug_search']['noresult_msg'] : $form_init_variables['drug_search']['noresult_msg']);
		return emd_search_php_form('drug_search', 'drug_search', 'emd_drug', $noresult_msg, 'drug_search', $atts);
	} else {
		$noaccess_msg = (isset($form_variables['drug_search']['noaccess_msg']) ? $form_variables['drug_search']['noaccess_msg'] : $form_init_variables['drug_search']['noaccess_msg']);
		return "<div class='alert alert-info not-authorized'>" . $noaccess_msg . "</div>";
	}
}
